@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,17 +32,29 @@
 
 using namespace GammaRay;
 
-ProbeControllerClient::ProbeControllerClient(QObject* parent): QObject(parent)
+ProbeControllerClient::ProbeControllerClient(QObject *parent)
+    : ProbeControllerInterface(parent)
 {
 }
 
+void ProbeControllerClient::selectObject(ObjectId id, const QString &toolId)
+{
+    Endpoint::instance()->invokeObject(objectName(), "selectObject",
+                                       QVariantList() << QVariant::fromValue(id) << toolId);
+}
+
+void ProbeControllerClient::requestSupportedTools(ObjectId id)
+{
+    Endpoint::instance()->invokeObject(objectName(), "requestSupportedTools",
+                                       QVariantList() << QVariant::fromValue(id));
+}
+
 void ProbeControllerClient::detachProbe()
 {
-  Endpoint::instance()->invokeObject(objectName(), "detachProbe");
+    Endpoint::instance()->invokeObject(objectName(), "detachProbe");
 }
 
 void ProbeControllerClient::quitHost()
 {
-  Endpoint::instance()->invokeObject(objectName(), "quitHost");
+    Endpoint::instance()->invokeObject(objectName(), "quitHost");
 }
-
