@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  acuordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -31,7 +36,6 @@
  * @brief A collection of custom model roles shared between client and server.
  */
 namespace GammaRay {
-
 /** Portable replacement for Qt::UserRole.
  * Qt4 uses 32, Qt5 256, use the latter globally to allow combining Qt4/5 client/servers.
  */
@@ -41,23 +45,24 @@ static const int UserRole = 256;
  * @todo These can be split again, between core tool model and UI tool model.
  */
 namespace ToolModelRole {
-  enum Role {
+enum Role {
     ToolFactory = UserRole + 1,
     ToolWidget,
     ToolId,
     ToolWidgetParent,
-    ToolEnabled
-  };
+    ToolEnabled,
+    ToolHasUi
+};
 }
 
 /** @brief Custom roles for GammaRay::ObjectMethodModel. */
 namespace ObjectMethodModelRole {
-  enum Role {
+enum Role {
     MetaMethod = UserRole + 1,
-    MetaMethodType
-  };
+    MetaMethodType,
+    MethodSignature
+};
 }
-
 }
 
 #endif
