@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  acuordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -22,39 +27,24 @@
 */
 
 #include "streamoperators.h"
-#include "enums.h"
 #include "metatypedeclarations.h"
 #include "variantwrapper.h"
+#include "sourcelocation.h"
 
-#include <QDataStream>
 #include <QMetaMethod>
 
 using namespace GammaRay;
 
-#define MAKE_ENUM_OPERATORS(enumType) \
-  QDataStream &operator<<(QDataStream &out, enumType value) \
-  { \
-    out << qint32(value); \
-    return out; \
-  } \
-  \
-  QDataStream &operator>>(QDataStream &in, enumType &value) \
-  { \
-    qint32 t; \
-    in >> t; \
-    value = static_cast<enumType>(t); \
-    return in; \
-  }
-
-MAKE_ENUM_OPERATORS(QMetaMethod::MethodType)
-MAKE_ENUM_OPERATORS(PropertyWidgetDisplayState::State)
-MAKE_ENUM_OPERATORS(Qt::ConnectionType)
+QT_BEGIN_NAMESPACE
+GAMMARAY_ENUM_STREAM_OPERATORS(QMetaMethod::MethodType)
+GAMMARAY_ENUM_STREAM_OPERATORS(Qt::ConnectionType)
+QT_END_NAMESPACE
 
 void StreamOperators::registerOperators()
 {
-  qRegisterMetaTypeStreamOperators<QMetaMethod::MethodType>();
-  qRegisterMetaTypeStreamOperators<PropertyWidgetDisplayState::State>();
-  qRegisterMetaTypeStreamOperators<Qt::ConnectionType>();
+    qRegisterMetaTypeStreamOperators<QMetaMethod::MethodType>();
+    qRegisterMetaTypeStreamOperators<Qt::ConnectionType>();
 
-  qRegisterMetaTypeStreamOperators<GammaRay::VariantWrapper>();
+    qRegisterMetaTypeStreamOperators<GammaRay::VariantWrapper>();
+    qRegisterMetaTypeStreamOperators<GammaRay::SourceLocation>();
 }
