@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,14 +32,15 @@
 #include <QObject>
 
 namespace GammaRay {
-
 /** @brief Client/Server interface of the property editor. */
 class PropertiesExtensionInterface : public QObject
 {
-  Q_OBJECT
-  Q_PROPERTY(bool canAddProperty READ canAddProperty WRITE setCanAddProperty NOTIFY canAddPropertyChanged)
-  Q_PROPERTY(bool hasPropertyValues READ hasPropertyValues WRITE setHasPropertyValues NOTIFY hasPropertyValuesChanged)
-  public:
+    Q_OBJECT
+    Q_PROPERTY(
+        bool canAddProperty READ canAddProperty WRITE setCanAddProperty NOTIFY canAddPropertyChanged)
+    Q_PROPERTY(
+        bool hasPropertyValues READ hasPropertyValues WRITE setHasPropertyValues NOTIFY hasPropertyValuesChanged)
+public:
     explicit PropertiesExtensionInterface(const QString &name, QObject *parent = 0);
     virtual ~PropertiesExtensionInterface();
 
@@ -51,22 +52,23 @@ class PropertiesExtensionInterface : public QObject
     bool hasPropertyValues() const;
     void setHasPropertyValues(bool hasValues);
 
-  public slots:
-    virtual void navigateToValue(int modelRow) = 0;
+public slots:
     virtual void setProperty(const QString &name, const QVariant &value) = 0;
 
-  signals:
+signals:
     void canAddPropertyChanged();
     void hasPropertyValuesChanged();
 
-  private:
+private:
     QString m_name;
     bool m_canAddProperty;
     bool m_hasPropertyValues;
 };
-
 }
 
-Q_DECLARE_INTERFACE(GammaRay::PropertiesExtensionInterface, "com.kdab.GammaRay.PropertiesExtensionInterface")
+QT_BEGIN_NAMESPACE
+Q_DECLARE_INTERFACE(GammaRay::PropertiesExtensionInterface,
+                    "com.kdab.GammaRay.PropertiesExtensionInterface")
+QT_END_NAMESPACE
 
 #endif // GAMMARAY_PROPERTIESEXTENSIONINTERFACE_H
