@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -34,26 +39,31 @@
 #define GAMMARAY_OBJECTMODELBASE_H
 
 #include "util.h"
+#include "objectdataprovider.h"
+
+#include <common/probecontrollerinterface.h>
 #include <common/objectmodel.h>
+#include <common/sourcelocation.h>
 
 #include <QModelIndex>
 #include <QObject>
 
 namespace GammaRay {
-
 /**
  * @brief A container for a generic Object Model derived from some Base.
  */
 template<typename Base>
 class ObjectModelBase : public Base
 {
-  public:
+public:
     /**
      * Constructor.
      * @param parent is the parent object for this instance.
      */
     explicit ObjectModelBase<Base>(QObject *parent) : Base(parent)
     {
+        qRegisterMetaType<ObjectId>();
+        qRegisterMetaTypeStreamOperators<ObjectId>();
     }
 
     /**
@@ -64,8 +74,8 @@ class ObjectModelBase : public Base
      */
     int columnCount(const QModelIndex &parent = QModelIndex()) const
     {
-      Q_UNUSED(parent);
-      return 2;
+        Q_UNUSED(parent);
+        return 2;
     }
 
     /**
@@ -79,30 +89,43 @@ class ObjectModelBase : public Base
      */
     QVariant dataForObject(QObject *object, const QModelIndex &index, int role) const
     {
-      if (role == Qt::DisplayRole) {
-        if (index.column() == 0) {
-          return
-            object->objectName().isEmpty() ?
-              Util::addressToString(object) :
-              object->objectName();
-        } else if (index.column() == 1) {
-          return object->metaObject()->className();
+        if (role == Qt::DisplayRole) {
+            if (index.column() == 0)
+                return Util::shortDisplayString(object);
+            else if (index.column() == 1)
+                return ObjectDataProvider::typeName(object);
+        } else if (role == ObjectModel::ObjectRole) {
+            return QVariant::fromValue(object);
+        } else if (role == ObjectModel::ObjectIdRole) {
+            return QVariant::fromValue(ObjectId(object));
+        } else if (role == Qt::ToolTipRole) {
+            return Util::tooltipForObject(object);
+        } else if (role == Qt::DecorationRole && index.column() == 0) {
+            return Util::iconForObject(object);
+        } else if (role == ObjectModel::CreationLocationRole) {
+            const auto loc = ObjectDataProvider::creationLocation(object);
+            if (loc.isValid())
+                return QVariant::fromValue(loc);
+        } else if (role == ObjectModel::DeclarationLocationRole) {
+            const auto loc = ObjectDataProvider::declarationLocation(object);
+            if (loc.isValid())
+                return QVariant::fromValue(loc);
         }
-      } else if (role == ObjectModel::ObjectRole) {
-        return QVariant::fromValue(object);
-      } else if (role == Qt::ToolTipRole) {
-          return
-            QObject::tr("<p style='white-space:pre'>Object name: %1\nType: %2\nParent: %3 (Address: %4)\nNumber of children: %5</p>").
-              arg(object->objectName().isEmpty() ? "&lt;Not set&gt;" : object->objectName()).
-              arg(object->metaObject()->className()).
-              arg(object->parent() ? object->parent()->metaObject()->className() : "<No parent>").
-              arg(Util::addressToString(object->parent())).
-              arg(object->children().size());
-      } else if (role == Qt::DecorationRole && index.column() == 0) {
-        return Util::iconForObject(object);
-      }
 
-      return QVariant();
+        return QVariant();
+    }
+
+    QMap<int, QVariant> itemData(const QModelIndex &index) const
+    {
+        QMap<int, QVariant> map = Base::itemData(index);
+        map.insert(ObjectModel::ObjectIdRole, this->data(index, ObjectModel::ObjectIdRole));
+        auto loc = this->data(index, ObjectModel::CreationLocationRole);
+        if (loc.isValid())
+            map.insert(ObjectModel::CreationLocationRole, loc);
+        loc = this->data(index, ObjectModel::DeclarationLocationRole);
+        if (loc.isValid())
+            map.insert(ObjectModel::DeclarationLocationRole, loc);
+        return map;
     }
 
     /**
@@ -118,18 +141,17 @@ class ObjectModelBase : public Base
      */
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const
     {
-      if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
-        switch (section) {
-        case 0:
-          return QObject::tr("Object");
-        case 1:
-          return QObject::tr("Type");
+        if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
+            switch (section) {
+            case 0:
+                return QObject::tr("Object");
+            case 1:
+                return QObject::tr("Type");
+            }
         }
-      }
-      return Base::headerData(section, orientation, role);
+        return Base::headerData(section, orientation, role);
     }
 };
-
 }
 
 #endif
