@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -33,7 +38,6 @@
 #include <QPointer>
 
 namespace GammaRay {
-
 class ToolFactory;
 class ProxyToolFactory;
 
@@ -44,32 +48,30 @@ typedef PluginManager<ToolFactory, ProxyToolFactory> ToolPluginManager;
  */
 class ToolModel : public QAbstractListModel
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit ToolModel(QObject *parent = 0);
     ~ToolModel();
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
-    virtual QVariant headerData(int section, Qt::Orientation orientation,
-                                int role = Qt::DisplayRole) const;
-    virtual QMap<int, QVariant> itemData(const QModelIndex& index) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QMap<int, QVariant> itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
 
     /** returns all tools provided by plugins for the ToolPluginModel. */
-    QVector<ToolFactory*> plugins() const;
+    QVector<ToolFactory *> plugins() const;
     /** returns all plugin load errors. */
     PluginLoadErrors pluginErrors() const;
-    /** returns the tool that is best suited to show information about \p object. */
-    QModelIndex toolForObject(QObject *object) const;
-    /** returns the tool that is best suited to show information about \p object. */
-    QModelIndex toolForObject(const void *object, const QString typeName) const;
+    /** returns the tools that are best suited to show information about \p object. */
+    QModelIndexList toolsForObject(QObject *object) const;
+    /** returns the tools that are best suited to show information about \p object. */
+    QModelIndexList toolsForObject(const void *object, const QString &typeName) const;
 
-  public slots:
+public slots:
+    QPair<int, QVariant> defaultSelectedItem() const;
     /** Check if we have to activate tools for this type */
     void objectAdded(QObject *obj);
-    void objectAddedMainThread(QObject *obj);
 
-  private:
+private:
     /**
      * Check if we have to activate tools for this type
      *
@@ -77,15 +79,15 @@ class ToolModel : public QAbstractListModel
      */
     void objectAdded(const QMetaObject *mo);
 
-    void addToolFactory(ToolFactory* tool);
+    void addToolFactory(ToolFactory *tool);
 
-  private:
-    QVector<ToolFactory*> m_tools;
-    QSet<ToolFactory*> m_inactiveTools;
+private:
+    QVector<ToolFactory *> m_tools;
+    QSet<ToolFactory *> m_inactiveTools;
+    QSet<const QMetaObject *> m_knownMetaObjects;
     QPointer<QWidget> m_parentWidget;
     QScopedPointer<ToolPluginManager> m_pluginManager;
 };
-
 }
 
 #endif // GAMMARAY_TOOLMODEL_H
