@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -30,33 +35,33 @@
 #include <QStandardItemModel>
 
 namespace GammaRay {
-
 class MimeTypesModel : public QStandardItemModel
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     enum Roles {
-      IconNameRole = UserRole + 1,
-      GenericIconNameRole
+        IconNameRole = UserRole + 1,
+        GenericIconNameRole
     };
 
     explicit MimeTypesModel(QObject *parent = 0);
     ~MimeTypesModel();
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
-  private:
+private:
     void fillModel();
-    QVector<QStandardItem*> itemsForType(const QString &mimeTypeName);
+    QVector<QStandardItem *> itemsForType(const QString &mimeTypeName);
     void makeItemsForType(const QString &mimeTypeName);
-    static QList<QStandardItem*> makeRowForType(const QMimeType &mt);
+    static QList<QStandardItem *> makeRowForType(const QMimeType &mt);
     QSet<QString> normalizedMimeTypeNames(const QStringList &typeNames) const;
 
-    QHash<QString, QVector<QStandardItem*> > m_mimeTypeNodes;
+    QHash<QString, QVector<QStandardItem *> > m_mimeTypeNodes;
     QMimeDatabase m_db;
+    bool m_modelFilled;
 };
-
 }
 
 #endif // GAMMARAY_MIMETYPESMODEL_H
