@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,6 +29,7 @@
 #include "abstractinjector.h"
 
 #include <QDebug>
+#include <QDir>
 #include <QStringList>
 
 using namespace GammaRay;
@@ -38,26 +39,24 @@ AbstractInjector::~AbstractInjector()
     stop();
 }
 
-bool AbstractInjector::launch(const QStringList &programAndArgs,
-                              const QString &probeDll,
-                              const QString &probeFunc,
-                              const QProcessEnvironment& env)
+bool AbstractInjector::launch(const QStringList &programAndArgs, const QString &probeDll,
+                              const QString &probeFunc, const QProcessEnvironment &env)
 {
-  Q_UNUSED(programAndArgs);
-  Q_UNUSED(probeDll);
-  Q_UNUSED(probeFunc);
-  Q_UNUSED(env);
-  qWarning() << "Injection on launch not supported by this injector.";
-  return false;
+    Q_UNUSED(programAndArgs);
+    Q_UNUSED(probeDll);
+    Q_UNUSED(probeFunc);
+    Q_UNUSED(env);
+    qWarning() << "Injection on launch not supported by this injector.";
+    return false;
 }
 
 bool AbstractInjector::attach(int pid, const QString &probeDll, const QString &probeFunc)
 {
-  Q_UNUSED(pid);
-  Q_UNUSED(probeDll);
-  Q_UNUSED(probeFunc);
-  qWarning() << "Attaching to a running process is not supported by this injector.";
-  return false;
+    Q_UNUSED(pid);
+    Q_UNUSED(probeDll);
+    Q_UNUSED(probeFunc);
+    qWarning() << "Attaching to a running process is not supported by this injector.";
+    return false;
 }
 
 bool AbstractInjector::selfTest()
@@ -68,3 +67,15 @@ bool AbstractInjector::selfTest()
 void AbstractInjector::stop()
 {
 }
+
+QString AbstractInjector::workingDirectory() const
+{
+    if (m_workingDir.isEmpty())
+        return QDir::currentPath();
+    return m_workingDir;
+}
+
+void AbstractInjector::setWorkingDirectory(const QString &path)
+{
+    m_workingDir = path;
+}
