@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,17 +32,18 @@
 #include <QProcess>
 #include <QSharedPointer>
 
+QT_BEGIN_NAMESPACE
 class QProcessEnvironment;
 class QString;
 class QStringList;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class AbstractInjector : public QObject
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     typedef QSharedPointer<AbstractInjector> Ptr;
     virtual ~AbstractInjector();
 
@@ -58,9 +59,8 @@ class AbstractInjector : public QObject
      *
      * @return True if the launch succeeded, false otherwise.
      */
-    virtual bool launch(const QStringList &programAndArgs,
-                        const QString &probeDll, const QString &probeFunc,
-                        const QProcessEnvironment &env);
+    virtual bool launch(const QStringList &programAndArgs, const QString &probeDll,
+                        const QString &probeFunc, const QProcessEnvironment &env);
 
     /**
      * Attach to the running application with process id @p pid
@@ -100,6 +100,11 @@ class AbstractInjector : public QObject
 
     virtual void stop();
 
+    /** Returns the working directory supposed to be used for launching. */
+    QString workingDirectory() const;
+    /** Set working directory for launching. */
+    void setWorkingDirectory(const QString &path);
+
 signals:
     void started();
     void finished();
@@ -107,8 +112,10 @@ signals:
 
     void stdoutMessage(const QString &message);
     void stderrMessage(const QString &message);
-};
 
+private:
+    QString m_workingDir;
+};
 }
 
 #endif // ABSTRACTINJECTOR_H
