@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Patrick Spendrin <ps_ml@gmx.de>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,31 +32,27 @@
 #include "abstractinjector.h"
 
 #include <qglobal.h>
-
-#ifdef Q_OS_WIN
-
 #include <QStringList>
-#include <windows.h>
+#include <qt_windows.h>
 
 namespace GammaRay {
 class FinishWaiter;
 class WinDllInjector : public AbstractInjector
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     WinDllInjector();
     ~WinDllInjector();
     QString name() const Q_DECL_OVERRIDE;
-    bool launch(const QStringList &programAndArgs,
-                const QString &probeDll, const QString &probeFunc,
-                const QProcessEnvironment &env) Q_DECL_OVERRIDE;
+    bool launch(const QStringList &programAndArgs, const QString &probeDll,
+                const QString &probeFunc, const QProcessEnvironment &env) Q_DECL_OVERRIDE;
     bool attach(int pid, const QString &probeDll, const QString &probeFunc) Q_DECL_OVERRIDE;
     int exitCode() Q_DECL_OVERRIDE;
     QProcess::ExitStatus exitStatus() Q_DECL_OVERRIDE;
     QProcess::ProcessError processError() Q_DECL_OVERRIDE;
     QString errorString() Q_DECL_OVERRIDE;
     void stop();
-  private:
+private:
     int mExitCode;
     QProcess::ProcessError mProcessError;
     QProcess::ExitStatus mExitStatus;
@@ -69,9 +65,6 @@ class WinDllInjector : public AbstractInjector
     FinishWaiter *m_injectThread;
     friend class FinishWaiter;
 };
-
 }
 
-#endif
-
 #endif // GAMMARAY_WINDLLINJECTOR_H
