@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -41,54 +41,54 @@
 using namespace GammaRay;
 
 FontBrowserServer::FontBrowserServer(ProbeInterface *probe, QObject *parent)
-  : FontBrowserInterface(parent)
-  , m_selectedFontModel(new FontModel(this))
+    : FontBrowserInterface(parent)
+    , m_selectedFontModel(new FontModel(this))
 {
-  auto model = new FontDatabaseModel(this);
-  probe->registerModel(QStringLiteral("com.kdab.GammaRay.FontModel"), model);
-  m_fontSelectionModel = ObjectBroker::selectionModel(model);
-  connect(m_fontSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-          SLOT(updateFonts()));
-  probe->registerModel(QStringLiteral("com.kdab.GammaRay.SelectedFontModel"), m_selectedFontModel);
+    auto model = new FontDatabaseModel(this);
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.FontModel"), model);
+    m_fontSelectionModel = ObjectBroker::selectionModel(model);
+    connect(m_fontSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+            SLOT(updateFonts()));
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.SelectedFontModel"),
+                         m_selectedFontModel);
 }
 
 void FontBrowserServer::updateFonts()
 {
-  const auto rows = m_fontSelectionModel->selectedRows();
-  QVector<QFont> currentFonts;
-  currentFonts.reserve(rows.size());
-  foreach (const QModelIndex &index, rows) {
-    currentFonts << index.data(Qt::UserRole + 1).value<QFont>();
-  }
-  m_selectedFontModel->updateFonts(currentFonts);
+    const auto rows = m_fontSelectionModel->selectedRows();
+    QVector<QFont> currentFonts;
+    currentFonts.reserve(rows.size());
+    foreach (const QModelIndex &index, rows)
+        currentFonts << index.data(Qt::UserRole + 1).value<QFont>();
+    m_selectedFontModel->updateFonts(currentFonts);
 }
 
 void FontBrowserServer::setPointSize(int size)
 {
-  m_selectedFontModel->setPointSize(size);
+    m_selectedFontModel->setPointSize(size);
 }
 
 void FontBrowserServer::toggleBoldFont(bool bold)
 {
-  m_selectedFontModel->toggleBoldFont(bold);
+    m_selectedFontModel->toggleBoldFont(bold);
 }
 
 void FontBrowserServer::toggleItalicFont(bool italic)
 {
-  m_selectedFontModel->toggleItalicFont(italic);
+    m_selectedFontModel->toggleItalicFont(italic);
 }
 
 void FontBrowserServer::toggleUnderlineFont(bool underline)
 {
-  m_selectedFontModel->toggleUnderlineFont(underline);
+    m_selectedFontModel->toggleUnderlineFont(underline);
 }
 
 void FontBrowserServer::updateText(const QString &text)
 {
-  m_selectedFontModel->updateText(text);
+    m_selectedFontModel->updateText(text);
 }
 
 void FontBrowserServer::setColors(const QColor &foreground, const QColor &background)
 {
-  m_selectedFontModel->setColors(foreground, background);
+    m_selectedFontModel->setColors(foreground, background);
 }
