@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -30,48 +35,46 @@
 class KJob;
 
 namespace GammaRay {
-
 class KJobModel : public QAbstractTableModel
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit KJobModel(QObject *parent = 0);
 
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
-    virtual QVariant headerData(int section, Qt::Orientation orientation,
-                                int role = Qt::DisplayRole) const;
+    QVariant headerData(int section, Qt::Orientation orientation,
+                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-  private slots:
+private slots:
     void objectAdded(QObject *obj);
     void objectRemoved(QObject *obj);
     void jobResult(KJob *job);
     void jobFinished(KJob *obj);
     void jobInfo(KJob *job, const QString &plainMessage);
 
-  private:
+private:
     int indexOfJob(QObject *obj) const;
 
     struct KJobInfo {
-      KJob *job;
-      QString name;
-      QString type;
-      QString statusText;
-      enum {
-        Running,
-        Finished,
-        Error,
-        Killed,
-        Deleted
-      } state;
+        KJob *job;
+        QString name;
+        QString type;
+        QString statusText;
+        enum {
+            Running,
+            Finished,
+            Error,
+            Killed,
+            Deleted
+        } state;
     };
     QVector<KJobInfo> m_data;
 };
-
 }
 
 #endif // GAMMARAY_KJOBMODEL_H
