@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -44,27 +44,22 @@ using namespace GammaRay;
 ///      was triggered and we close the mainwindow.
 
 ScriptEngineDebugger::ScriptEngineDebugger(ProbeInterface *probe, QObject *parent)
-  : QObject(parent)
+    : QObject(parent)
 {
-  ObjectTypeFilterProxyModel<QScriptEngine> *scriptEngineFilter =
-    new ObjectTypeFilterProxyModel<QScriptEngine>(this);
-  scriptEngineFilter->setSourceModel(probe->objectListModel());
-  SingleColumnObjectProxyModel *singleColumnProxy =
-    new SingleColumnObjectProxyModel(this);
-  singleColumnProxy->setSourceModel(scriptEngineFilter);
+    ObjectTypeFilterProxyModel<QScriptEngine> *scriptEngineFilter
+        = new ObjectTypeFilterProxyModel<QScriptEngine>(this);
+    scriptEngineFilter->setSourceModel(probe->objectListModel());
+    SingleColumnObjectProxyModel *singleColumnProxy
+        = new SingleColumnObjectProxyModel(this);
+    singleColumnProxy->setSourceModel(scriptEngineFilter);
 
-  probe->registerModel(QStringLiteral("com.kdab.GammaRay.ScriptEngines"), singleColumnProxy);
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.ScriptEngines"), singleColumnProxy);
 }
 
 ScriptEngineDebugger::~ScriptEngineDebugger()
 {
 }
 
-QString ScriptEngineDebuggerFactory::name() const
-{
-  return tr("Script Engines");
-}
-
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN(ScriptEngineDebuggerFactory)
 #endif
