@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -46,34 +46,37 @@ using namespace GammaRay;
 ///      was triggered and we close the mainwindow.
 
 ScriptEngineDebuggerWidget::ScriptEngineDebuggerWidget(QWidget *parent)
-  : QWidget(parent), ui(new Ui::ScriptEngineDebuggerWidget), debugger(new QScriptEngineDebugger(this))
+    : QWidget(parent)
+    , ui(new Ui::ScriptEngineDebuggerWidget)
+    , m_stateManager(this)
+    , debugger(new QScriptEngineDebugger(this))
 {
-  ui->setupUi(this);
-  ui->scriptEngineComboBox->setModel(ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.ScriptEngines")));
-  connect(ui->scriptEngineComboBox, SIGNAL(activated(int)), SLOT(scriptEngineSelected(int)));
+    ui->setupUi(this);
+    ui->scriptEngineComboBox->setModel(ObjectBroker::model(QStringLiteral(
+                                                               "com.kdab.GammaRay.ScriptEngines")));
+    connect(ui->scriptEngineComboBox, SIGNAL(activated(int)), SLOT(scriptEngineSelected(int)));
 
-  ui->verticalLayout_10->addWidget(debugger->standardWindow());
+    ui->verticalLayout_10->addWidget(debugger->standardWindow());
 
-  if (ui->scriptEngineComboBox->count()) {
-    scriptEngineSelected(0);
-  }
+    if (ui->scriptEngineComboBox->count())
+        scriptEngineSelected(0);
 }
 
 ScriptEngineDebuggerWidget::~ScriptEngineDebuggerWidget()
 {
-  debugger->detach();
+    debugger->detach();
 }
 
 void ScriptEngineDebuggerWidget::scriptEngineSelected(int index)
 {
-  QObject *obj =
-    ui->scriptEngineComboBox->itemData(index, ObjectModel::ObjectRole).value<QObject*>();
-  QScriptEngine *engine = qobject_cast<QScriptEngine*>(obj);
-  if (engine) {
-    debugger->attachTo(engine);
+    QObject *obj
+        = ui->scriptEngineComboBox->itemData(index, ObjectModel::ObjectRole).value<QObject *>();
+    QScriptEngine *engine = qobject_cast<QScriptEngine *>(obj);
+    if (engine) {
+        debugger->attachTo(engine);
 // FIXME: if we'd do that, we'd get crashes on shutdown.
-//     debugger->action(QScriptEngineDebugger::InterruptAction)->trigger();
-  }
+// debugger->action(QScriptEngineDebugger::InterruptAction)->trigger();
+    }
 }
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
