@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,37 +33,37 @@
 
 #include <QItemSelectionModel>
 
+QT_BEGIN_NAMESPACE
 class QAbstractProxyModel;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class SelectionModelInspector : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit SelectionModelInspector(ProbeInterface *probe, QObject *parent = 0);
 
-  private slots:
+private slots:
     void currentChanged(const QModelIndex &current);
 
-  private:
+private:
     QAbstractProxyModel *m_current;
 };
 
-class SelectionModelInspectorFactory :
-    public QObject, public StandardToolFactory<QItemSelectionModel, SelectionModelInspector>
+class SelectionModelInspectorFactory : public QObject,
+    public StandardToolFactory<QItemSelectionModel, SelectionModelInspector>
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolFactory)
-  Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_selectionmodelinspector.json")
-  public:
-    explicit SelectionModelInspectorFactory(QObject *parent = 0) : QObject(parent)
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolFactory)
+    Q_PLUGIN_METADATA(
+        IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_selectionmodelinspector.json")
+public:
+    explicit SelectionModelInspectorFactory(QObject *parent = 0)
+        : QObject(parent)
     {
     }
-
-    QString name() const Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_SELECTIONMODELINSPECTOR_H
