@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,20 +32,18 @@
 #include "styleinspectorinterface.h"
 
 namespace GammaRay {
-
 class StyleInspectorClient : public StyleInspectorInterface
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::StyleInspectorInterface)
-  public:
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::StyleInspectorInterface)
+public:
     explicit StyleInspectorClient(QObject *parent = 0);
-    virtual ~StyleInspectorClient();
+    ~StyleInspectorClient();
 
-    virtual void setCellHeight(int height);
-    virtual void setCellWidth(int width);
-    virtual void setCellZoom(int zoom);
+    void setCellHeight(int height) Q_DECL_OVERRIDE;
+    void setCellWidth(int width) Q_DECL_OVERRIDE;
+    void setCellZoom(int zoom) Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_STYLEINSPECTORCLIENT_H
