@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -43,7 +43,7 @@ using namespace GammaRay;
 // BUG: Some QTimers appear as free timers
 // BUG: QTimeLine class name not shown
 // BUG: No thread safety yet
-//          Related: Protect against timer deletion
+// Related: Protect against timer deletion
 // BUG: Sorting in the view doesn't work well
 // BUG: Only top-level timers are shown (bug in probe)
 
@@ -57,50 +57,47 @@ using namespace GammaRay;
 // Add clear button that removes all free timers and resets statistics for normal timers
 // Add big fat "total wakeups / sec" label to the status bar
 // Retrieve receiver name from connection model
-//     Add to view as column: receivers: slotXYZ and 3 others (shown in tooltip)
+// Add to view as column: receivers: slotXYZ and 3 others (shown in tooltip)
 // Move signal hook to probe interface
-//     Then maybe add general signal profiler plugin, or even visualization
+// Then maybe add general signal profiler plugin, or even visualization
 // Flash delegate when timer triggered
 // Color cell in view redish, depending on how active the timer is
 
 class TimerFilterModel : public ObjectTypeFilterProxyModel<QTimer>
 {
-  public:
-    explicit TimerFilterModel(QObject *parent) : ObjectTypeFilterProxyModel<QTimer>(parent) {}
+public:
+    explicit TimerFilterModel(QObject *parent)
+        : ObjectTypeFilterProxyModel<QTimer>(parent) {}
 
     bool filterAcceptsObject(QObject *object) const Q_DECL_OVERRIDE
     {
-      if (object && object->inherits("QQmlTimer"))
-        return true;
-      return ObjectTypeFilterProxyModel<QTimer>::filterAcceptsObject(object);
+        if (object && object->inherits("QQmlTimer"))
+            return true;
+        return ObjectTypeFilterProxyModel<QTimer>::filterAcceptsObject(object);
     }
 };
 
-
 TimerTop::TimerTop(ProbeInterface *probe, QObject *parent)
-  : QObject(parent),
-    m_updateTimer(new QTimer(this))
+    : QObject(parent)
+    , m_updateTimer(new QTimer(this))
 {
-  Q_ASSERT(probe);
+    Q_ASSERT(probe);
 
-  QSortFilterProxyModel* const filterModel = new TimerFilterModel(this);
-  filterModel->setDynamicSortFilter(true);
-  filterModel->setSourceModel(probe->objectListModel());
-  TimerModel::instance()->setParent(this); // otherwise it's not filtered out
-  TimerModel::instance()->setProbe(probe);
-  TimerModel::instance()->setSourceModel(filterModel);
+    QSortFilterProxyModel * const filterModel = new TimerFilterModel(this);
+    filterModel->setDynamicSortFilter(true);
+    filterModel->setSourceModel(probe->objectListModel());
+    TimerModel::instance()->setParent(this); // otherwise it's not filtered out
+    TimerModel::instance()->setProbe(probe);
+    TimerModel::instance()->setSourceModel(filterModel);
 
-  probe->registerModel(QStringLiteral("com.kdab.GammaRay.TimerModel"), TimerModel::instance());
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.TimerModel"), TimerModel::instance());
 }
 
-QString TimerTopFactory::name() const
+TimerTopFactory::TimerTopFactory(QObject *parent)
+    : QObject(parent)
 {
-  return tr("Timers");
-}
-
-QStringList TimerTopFactory::supportedTypes() const
-{
-  return QStringList() << QStringLiteral("QObject") << QStringLiteral("QTimer");
+    setSupportedTypes(QVector<QByteArray>() << QByteArrayLiteral("QObject")
+                                            << QByteArrayLiteral("QTimer"));
 }
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
