@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,38 +33,29 @@
 #include <QTimer>
 
 namespace GammaRay {
-
 namespace Ui {
-  class TimerTop;
+class TimerTop;
 }
 
 class TimerTop : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit TimerTop(ProbeInterface *probe, QObject *parent = 0);
 
-  private:
+private:
     QTimer *m_updateTimer;
 };
 
-class TimerTopFactory : public QObject,
-                        public StandardToolFactory<QTimer, TimerTop>
+class TimerTopFactory : public QObject, public StandardToolFactory<QTimer, TimerTop>
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolFactory)
-  Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_timertop.json")
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolFactory)
+    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_timertop.json")
 
-  public:
-    explicit TimerTopFactory(QObject *parent = 0) : QObject(parent)
-    {
-    }
-
-    QString name() const Q_DECL_OVERRIDE;
-
-    QStringList supportedTypes() const Q_DECL_OVERRIDE;
+public:
+    explicit TimerTopFactory(QObject *parent = 0);
 };
-
 }
 
 #endif // GAMMARAY_SCENEINSPECTOR_H
