@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Thomas McGuire <thomas.mcguire@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -23,40 +28,39 @@
 #ifndef GAMMARAY_TIMERTOP_TIMERTOPWIDGET_H
 #define GAMMARAY_TIMERTOP_TIMERTOPWIDGET_H
 
+#include <ui/uistatemanager.h>
 #include <ui/tooluifactory.h>
 
 #include <QWidget>
 
+QT_BEGIN_NAMESPACE
 class QTimer;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 namespace Ui {
-  class TimerTopWidget;
+class TimerTopWidget;
 }
 
 class TimerTopWidget : public QWidget
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit TimerTopWidget(QWidget *parent = 0);
     ~TimerTopWidget();
 
-  private slots:
-    void slotUpdateView();
-
-  private:
+private:
     QScopedPointer<Ui::TimerTopWidget> ui;
+    UIStateManager m_stateManager;
     QTimer *m_updateTimer;
 };
 
 class TimerTopUiFactory : public QObject, public StandardToolUiFactory<TimerTopWidget>
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolUiFactory)
-  Q_PLUGIN_METADATA(IID "com.kdab.gammaray.TimerTopUi")
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolUiFactory)
+    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolUiFactory" FILE "gammaray_timertop.json")
 };
-
 }
 
 #endif // GAMMARAY_TIMERTOPWIDGET_H
