@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,32 +32,27 @@
 #include <core/toolfactory.h>
 
 namespace GammaRay {
-
 class WebInspector : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit WebInspector(GammaRay::ProbeInterface *probe, QObject *parent = 0);
 
-  private slots:
+private slots:
     void objectAdded(QObject *obj);
 };
 
 class WebInspectorFactory : public QObject, public ToolFactory
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolFactory)
-  Q_PLUGIN_METADATA(IID "com.kdab.gammaray.WebInspector")
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolFactory)
+    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_webinspector.json")
 
-  public:
+public:
     explicit WebInspectorFactory(QObject *parent = 0);
-    QString id() const;
-    QString name() const;
-    void init(ProbeInterface* probe);
-    QStringList supportedTypes() const;
-    bool isHidden() const;
+    QString id() const Q_DECL_OVERRIDE;
+    void init(ProbeInterface *probe) Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_WEBINSPECTOR_H
