@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -25,20 +30,36 @@
 #define GAMMARAY_WIDGETINSPECTOR_WIDGETINSPECTORINTERFACE_H
 
 #include <QObject>
+#include <QMetaType>
 
-class QPixmap;
+QT_BEGIN_NAMESPACE
+class QImage;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class WidgetInspectorInterface : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+    Q_PROPERTY(
+        GammaRay::WidgetInspectorInterface::Features features READ features WRITE setFeatures NOTIFY featuresChanged)
+public:
+    enum Feature {
+        NoFeature = 0,
+        InputRedirection = 1,
+        AnalyzePainting = 2,
+        SvgExport = 4,
+        PdfExport = 8,
+        UiExport = 16
+    };
+    Q_DECLARE_FLAGS(Features, Feature)
+
     explicit WidgetInspectorInterface(QObject *parent = 0);
     virtual ~WidgetInspectorInterface();
 
-  public slots:
-    virtual void checkFeatures() = 0;
+    Features features() const;
+    void setFeatures(Features features);
+
+public slots:
     virtual void saveAsImage(const QString &fileName) = 0;
     virtual void saveAsSvg(const QString &fileName) = 0;
     virtual void saveAsPdf(const QString &fileName) = 0;
@@ -46,14 +67,18 @@ class WidgetInspectorInterface : public QObject
 
     virtual void analyzePainting() = 0;
 
-  signals:
-    void widgetPreviewAvailable(const QPixmap &pixmap);
-    void paintAnalyzed(const QPixmap &pixmap);
-    void features(bool svg, bool print, bool designer, bool privateHeaders);
-};
+signals:
+    void featuresChanged();
 
+private:
+    Features m_features;
+};
 }
 
+Q_DECLARE_METATYPE(GammaRay::WidgetInspectorInterface::Features)
+Q_DECLARE_OPERATORS_FOR_FLAGS(GammaRay::WidgetInspectorInterface::Features)
+QT_BEGIN_NAMESPACE
 Q_DECLARE_INTERFACE(GammaRay::WidgetInspectorInterface, "com.kdab.GammaRay.WidgetInspector")
+QT_END_NAMESPACE
 
 #endif // GAMMARAY_WIDGETINSPECTORINTERFACE_H
