@@ -4,10 +4,15 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,73 +32,70 @@
 
 #include <widgetinspectorinterface.h>
 
-#include <QLibrary>
 #include <QPointer>
 
+QT_BEGIN_NAMESPACE
 class QModelIndex;
 class QItemSelection;
 class QItemSelectionModel;
-class QTimer;
+class QLibrary;
+class QPoint;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class ProbeInterface;
 class PropertyController;
 class OverlayWidget;
-class PaintBufferModel;
+class PaintAnalyzer;
+class RemoteViewServer;
 
 class WidgetInspectorServer : public WidgetInspectorInterface
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::WidgetInspectorInterface)
-  public:
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::WidgetInspectorInterface)
+public:
     explicit WidgetInspectorServer(ProbeInterface *probe, QObject *parent = 0);
     ~WidgetInspectorServer();
 
-    void selectDefaultItem();
+protected:
+    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
 
-  protected:
-    bool eventFilter(QObject *object, QEvent *event);
-
-  private:
+private:
     void callExternalExportAction(const char *name, QWidget *widget, const QString &fileName);
-    QPixmap pixmapForWidget(QWidget *widget);
+    QImage imageForWidget(QWidget *widget);
     void registerWidgetMetaTypes();
     void registerVariantHandlers();
     void discoverObjects();
+    void checkFeatures();
 
-  private slots:
+private slots:
     void widgetSelected(const QItemSelection &selection);
     void widgetSelected(QWidget *widget);
+    void objectSelected(QObject *obj);
     void objectCreated(QObject *object);
 
     void recreateOverlayWidget();
 
-    void saveAsImage(const QString &fileName);
-    void saveAsSvg(const QString &fileName);
-    void saveAsPdf(const QString &fileName);
-    void saveAsUiFile(const QString &fileName);
+    void saveAsImage(const QString &fileName) Q_DECL_OVERRIDE;
+    void saveAsSvg(const QString &fileName) Q_DECL_OVERRIDE;
+    void saveAsPdf(const QString &fileName) Q_DECL_OVERRIDE;
+    void saveAsUiFile(const QString &fileName) Q_DECL_OVERRIDE;
 
-    void analyzePainting();
-    void eventuallyUpdatePaintAnalyzer();
-    void updatePaintAnalyzer();
+    void analyzePainting() Q_DECL_OVERRIDE;
 
     void updateWidgetPreview();
+    void pickElement(const QPoint &pos);
 
-    void checkFeatures();
-
-  private:
+private:
     QPointer<OverlayWidget> m_overlayWidget;
-    QLibrary m_externalExportActions;
+    QLibrary *m_externalExportActions;
     PropertyController *m_propertyController;
     QItemSelectionModel *m_widgetSelectionModel;
     QPointer<QWidget> m_selectedWidget;
-    QTimer *m_updatePreviewTimer;
-    PaintBufferModel *m_paintBufferModel;
-    QTimer *m_paintAnalyzerTimer;
+    PaintAnalyzer *m_paintAnalyzer;
+    RemoteViewServer *m_remoteView;
     ProbeInterface *m_probe;
 };
-
 }
 
 #endif // GAMMARAY_WIDGETINSPECTORSERVER_H
