@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,21 +32,22 @@
 #include <core/objecttypefilterproxymodel.h>
 
 namespace GammaRay {
-
 /** Widget tree model.
  * @todo Show layout hierarchy instead of object hierarchy.
  */
 class WidgetTreeModel : public ObjectFilterProxyModelBase
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit WidgetTreeModel(QObject *parent = 0);
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-  protected:
-    virtual bool filterAcceptsObject(QObject *object) const;
+public slots:
+    QPair<int, QVariant> defaultSelectedItem() const;
+
+protected:
+    bool filterAcceptsObject(QObject *object) const Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_WIDGETTREEMODEL_H
