@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,28 +31,28 @@
 
 using namespace GammaRay;
 
-AboutDialog::AboutDialog(QWidget* parent): QDialog(parent),
-  ui(new Ui::AboutDialog)
+AboutDialog::AboutDialog(QWidget *parent)
+    : QDialog(parent)
+    , ui(new Ui::AboutDialog)
 {
-  ui->setupUi(this);
+    ui->setupUi(this);
 }
 
 AboutDialog::~AboutDialog()
 {
 }
 
-void AboutDialog::setTitle(const QString& title)
+void AboutDialog::setTitle(const QString &title)
 {
-  ui->titleLabel->setText(title);
+    ui->titleLabel->setText(title);
 }
 
-void AboutDialog::setText(const QString& text)
+void AboutDialog::setText(const QString &text)
 {
-  ui->textLabel->setText(text);
+    ui->textLabel->setText(text);
 }
 
-void AboutDialog::setLogo(const QString& iconFileName)
+void AboutDialog::setLogo(const QString &iconFileName)
 {
-  ui->logoLabel->setPixmap(iconFileName);
+    ui->logoLabel->setPixmap(iconFileName);
 }
-
