@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -30,11 +35,10 @@
 #include <QVector>
 
 namespace GammaRay {
-
 /** Item editor factory with support for extra types while keeping support for the built-in ones. */
 class GAMMARAY_UI_EXPORT PropertyEditorFactory : public QItemEditorFactory
 {
-  public:
+public:
     static PropertyEditorFactory *instance();
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
@@ -43,20 +47,20 @@ class GAMMARAY_UI_EXPORT PropertyEditorFactory : public QItemEditorFactory
     typedef int TypeId;
 #endif
 
-    QWidget *createEditor(TypeId type, QWidget *parent) const;
+    QWidget *createEditor(TypeId type, QWidget *parent) const Q_DECL_OVERRIDE;
 
     static QVector<int> supportedTypes();
 
-  protected:
+protected:
     PropertyEditorFactory();
 
-  private:
+private:
+    Q_DISABLE_COPY(PropertyEditorFactory)
     void initBuiltInTypes();
     void addEditor(TypeId type, QItemEditorCreatorBase *creator);
 
     QVector<int> m_supportedTypes;
 };
-
 }
 
 #endif // GAMMARAY_PROPERTYEDITORFACTORY_H
