@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,33 +33,34 @@
 #include <QWidget>
 
 namespace GammaRay {
-
 namespace Ui {
-  class PropertyExtendedEditor;
+class PropertyExtendedEditor;
 }
 
 /** Base class for property editors that open a separate dialog. */
 class PropertyExtendedEditor : public QWidget
 {
-  Q_OBJECT
-  Q_PROPERTY(QVariant value READ value WRITE setValue USER true)
-  public:
+    Q_OBJECT
+    Q_PROPERTY(QVariant value READ value WRITE setValue USER true)
+public:
     explicit PropertyExtendedEditor(QWidget *parent = 0);
     virtual ~PropertyExtendedEditor();
 
+    Qt::Alignment alignment() const;
+    void setAlignment(const Qt::Alignment &alignment);
+
     QVariant value() const;
     void setValue(const QVariant &value);
 
     void save(const QVariant &value);
 
-  protected slots:
+protected slots:
     virtual void edit() = 0;
 
-  private:
+private:
     Ui::PropertyExtendedEditor *ui;
     QVariant m_value;
 };
-
 }
 
 #endif // GAMMARAY_PROPERTYEXTENDEDEDITOR_H
