@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,16 +33,14 @@
 using namespace GammaRay;
 
 PropertyFontEditor::PropertyFontEditor(QWidget *parent)
-  : PropertyExtendedEditor(parent)
+    : PropertyExtendedEditor(parent)
 {
 }
 
 void PropertyFontEditor::edit()
 {
-  bool ok = false;
-  const QFont font = QFontDialog::getFont(&ok, value().value<QFont>(), this);
-  if (ok) {
-    save(font);
-  }
+    bool ok = false;
+    const QFont font = QFontDialog::getFont(&ok, value().value<QFont>(), this);
+    if (ok)
+        save(font);
 }
-
