@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,17 +32,15 @@
 #include "propertyextendededitor.h"
 
 namespace GammaRay {
-
 class PropertyFontEditor : public PropertyExtendedEditor
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit PropertyFontEditor(QWidget *parent = 0);
 
-  protected:
-    virtual void edit();
+protected:
+    void edit() Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_PROPERTYFONTEDITOR_H
