@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,25 +29,26 @@
 #ifndef GAMMARAY_MIMETYPESWIDGET_H
 #define GAMMARAY_MIMETYPESWIDGET_H
 
+#include <ui/uistatemanager.h>
+
 #include <QWidget>
 
 namespace GammaRay {
-
 namespace Ui {
-  class MimeTypesWidget;
+class MimeTypesWidget;
 }
 
 class MimeTypesWidget : public QWidget
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit MimeTypesWidget(QWidget *parent = 0);
     ~MimeTypesWidget();
 
-  private:
+private:
     QScopedPointer<Ui::MimeTypesWidget> ui;
+    UIStateManager m_stateManager;
 };
-
 }
 
 #endif // GAMMARAY_MIMETYPESWIDGET_H
