@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,20 +32,19 @@
 #include <common/tools/objectinspector/methodsextensioninterface.h>
 
 namespace GammaRay {
-
 class MethodsExtensionClient : public MethodsExtensionInterface
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::MethodsExtensionInterface)
-  public:
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::MethodsExtensionInterface)
+public:
     explicit MethodsExtensionClient(const QString &name, QObject *parent = 0);
-    virtual ~MethodsExtensionClient();
+    ~MethodsExtensionClient();
 
-  public slots:
-    virtual void activateMethod();
-    virtual void invokeMethod(Qt::ConnectionType type);
+public slots:
+    void activateMethod() Q_DECL_OVERRIDE;
+    void invokeMethod(Qt::ConnectionType type) Q_DECL_OVERRIDE;
+    void connectToSignal() Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_METHODSEXTENSIONCLIENT_H
