@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,10 +31,11 @@
 
 #include <QWidget>
 
+QT_BEGIN_NAMESPACE
 class QModelIndex;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class PropertiesExtensionInterface;
 
 class Ui_PropertiesTab;
@@ -42,28 +43,27 @@ class PropertyWidget;
 
 class PropertiesTab : public QWidget
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit PropertiesTab(PropertyWidget *parent);
     virtual ~PropertiesTab();
 
-  private:
+private:
     void setObjectBaseName(const QString &baseName);
 
-  private slots:
+private slots:
     void updateNewPropertyValueEditor();
     void validateNewProperty();
     void propertyContextMenu(const QPoint &pos);
     void addNewProperty();
     void hasValuesChanged();
 
-  private:
+private:
     Ui_PropertiesTab *m_ui;
     PropertiesExtensionInterface *m_interface;
 
     QWidget *m_newPropertyValue;
 };
-
 }
 
 #endif // PROPERTIESTAB_H
